@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
+import logging
 import inspect
 import locale
 import os
@@ -16,6 +17,7 @@ from . import settings, global_cache_map
 from ..uqer import session
 from ..config import *
 from ..version import __version__
+from ..utils import format_print
 
 from platform import python_version
 import json
@@ -55,6 +57,8 @@ def get_http_result(httpClient, requestString, gw, max_retries=max_retries):
 
         except Exception as e:
             time.sleep(retry_interval)
+            if i >= max_retries:
+                raise e
 
 
 def __getCSV__(requestString, httpClient, gw=True):
@@ -90,7 +94,7 @@ def splist(l, s):
 def is_no_data_warn(csvString, print_msg):
     if csvString.startswith('-1:No Data Returned'):
         if print_msg:
-            print('没有数据返回。请检查输入参数，若仍有问题，可联系service.uqer@datayes.com')
+            format_print('没有数据返回。请检查输入参数，若仍有问题，可联系service.uqer@datayes.com', with_date=True)
         return True
     return False
 
@@ -121,7 +125,7 @@ def handle_error(csvString, api_name):
     else:
         result = csvString
     err_msg = result
-    print (err_msg)
+    format_print(err_msg, with_date=True)
 
     raise Exception(get_real_string(err_msg))
 
@@ -144,11 +148,11 @@ def get_token():
 
             return token
         except:
-            print ('获取通联数据权限凭证出错，可能是您的token无效或者token过期，请重新登录\n')
+            format_print('获取通联数据权限凭证出错，可能是您的token无效或者token过期，请重新登录\n', with_date=True)
 
             return ''
     else:
-        print ('当前环境下没有 token，可能是您未登录，请先登录哦')
+        format_print('当前环境下没有 token，可能是您未登录，请先登录哦', with_date=True)
         return ''
 
 def __getConn__():
@@ -192,9 +196,9 @@ def showtraceback(self, exc_tuple=None, filename=None, tb_offset=None,
             break
 
     if lineno:
-        print('行号: %s\n代码: %s\n%s' %(lineno, text, last_message))
+        format_print('行号: %s\n代码: %s\n%s' %(lineno, text, last_message), with_date=True)
     else:
-        print(last_message)
+        format_print(last_message, with_date=True)
 
 
 def pretty_traceback():
@@ -271,4 +275,4 @@ def replace_api_files():
     version_file_path = os.path.join(dir_path, 'version.py')
     with open(version_file_path, 'w') as f:
         f.write(version_str)
-        print('UQER SDK的DataAPI模块版本由%s升级到%s'%(dataapi_version, remote_version))
\ No newline at end of file
+        format_print('UQER SDK的DataAPI模块版本由%s升级到%s'%(dataapi_version, remote_version))
\ No newline at end of file
