@@ -1,11 +1,7 @@
 # -*- coding: utf-8 -*-
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 # 通联数据机密
 # --------------------------------------------------------------------
-# 通联数据股份公司版权所有 © 2013-2019
+# 通联数据股份公司版权所有 © 2013-2021
 #
 # 注意：本文所载所有信息均属于通联数据股份公司资产。本文所包含的知识和技术概念均属于
 # 通联数据产权，并可能由中国、美国和其他国家专利或申请中的专利所覆盖，并受商业秘密或
@@ -14,7 +10,7 @@ from __future__ import unicode_literals
 #
 # DataYes CONFIDENTIAL
 # --------------------------------------------------------------------
-# Copyright © 2013-2019 DataYes, All Rights Reserved.
+# Copyright © 2013-2021 DataYes, All Rights Reserved.
 #
 # NOTICE: All information contained herein is the property of DataYes
 # Incorporated. The intellectual and technical concepts contained herein are
@@ -61,10 +57,10 @@ def ideal(
     :param start_date: str, 'YYYYmmdd'
     :param end_date: str, 'YYYYmmdd'
     :param freq: str, 调仓频率，'day/week/month/quarter/semi-year'
-    :param universe: str or dict of list, 股票池。默认是HS300，目前支持HS300/ZZ500/ZZ700/ZZ800/TLQA,
+    :param universe: str or dict of list, 股票池。默认是HS300，目前支持HS300/ZZ500/ZZ700/ZZ800/TLQA/SH50/SC50/ZZ1000/ZZQZ,
             也可为dict of list，则为自定义universe
     :param benchmark: str/dict of Series/dict of dict, 优化基准。
-                      支持指数成份股 HS300/ZZ500/ZZ700/ZZ800/TLQA/risk_free/SH50。默认为HS300
+                      支持指数成份股 HS300/ZZ500/ZZ700/ZZ800/TLQA/risk_free/SH50/SC50/ZZ1000/ZZQZ。默认为HS300
                       支持自定义指数,即dict of Series/dict of dict形式定义的benchmark
     :param init_cash: int/float, 初始资金，默认1e8
     :param init_holding: dict/pd.Series/None, 每个个股的初始市值，不包含现金
@@ -114,10 +110,10 @@ def long_only(
     :param start_date: str, 'YYYYmmdd'
     :param end_date: str, 'YYYYmmdd'
     :param freq: str, 调仓频率，'day/week/month/quarter/semi-year'
-    :param universe: str or dict, 股票池。默认是HS300，目前支持HS300/ZZ500/ZZ700/ZZ800/TLQA,
+    :param universe: str or dict, 股票池。默认是HS300，目前支持HS300/ZZ500/ZZ700/ZZ800/TLQA/SH50/SC50/ZZ1000/ZZQZ,
             也可为dict of list，则为自定义universe
     :param benchmark: str/dict of Series/dict of dict, 优化基准。
-                      支持指数成份股 HS300/ZZ500/ZZ700/ZZ800/TLQA/risk_free/SH50。默认为HS300
+                      支持指数成份股 HS300/ZZ500/ZZ700/ZZ800/TLQA/risk_free/SH50/SC50/ZZ1000/ZZQZ。默认为HS300
                       支持自定义指数,即dict of Series/dict of dict形式定义的benchmark
     :param top_ratio: float/list 做多前多少百分比或者前百分比区间的股票，默认0.2
     :param select_type: int，组合构建的行业配比方式，默认为1。可选0/1 WHOLE_INDUSTRY = 0 EACH_INDUSTRY = 1
@@ -173,10 +169,10 @@ def long_short(
     :param start_date: str, 'YYYYmmdd'
     :param end_date: str, 'YYYYmmdd'
     :param freq: str, 调仓频率，'day/week/month/quarter/semi-year'
-    :param universe: str or dict, 股票池。默认是HS300，目前支持HS300/ZZ500/ZZ700/ZZ800/TLQA,
+    :param universe: str or dict, 股票池。默认是HS300，目前支持HS300/ZZ500/ZZ700/ZZ800/TLQA/SH50/SC50/ZZ1000/ZZQZ,
             也可为dict of list，则为自定义universe
     :param benchmark: str/dict of Series/dict of dict, 优化基准。
-                      支持指数成份股 HS300/ZZ500/ZZ700/ZZ800/TLQA/risk_free/SH50。默认为HS300
+                      支持指数成份股 HS300/ZZ500/ZZ700/ZZ800/TLQA/risk_free/SH50/SC50/ZZ1000/ZZQZ。默认为HS300
                       支持自定义指数,即dict of Series/dict of dict形式定义的benchmark
     :param top_ratio: float/list 做多前多少百分比或者前百分比区间的股票，默认0.2
     :param down_ratio: float 做空后多少百分比的股票，默认0.2
@@ -238,10 +234,10 @@ def limit_active_risk(
     :param start_date: str, 'YYYYmmdd'
     :param end_date: str, 'YYYYmmdd'
     :param freq: str, 调仓频率，'day/week/month/quarter/semi-year'
-    :param universe: str or dict, 股票池。默认是HS300，目前支持HS300/ZZ500/ZZ700/ZZ800/TLQA,
+    :param universe: str or dict, 股票池。默认是HS300，目前支持HS300/ZZ500/ZZ700/ZZ800/TLQA/SH50/SC50/ZZ1000/ZZQZ,
             也可为dict of list，则为自定义universe
     :param benchmark: str/dict of Series/dict of dict, 优化基准。
-                      支持指数成份股 HS300/ZZ500/ZZ700/ZZ800/TLQA/risk_free/SH50。默认为HS300
+                      支持指数成份股 HS300/ZZ500/ZZ700/ZZ800/TLQA/risk_free/SH50/SC50/ZZ1000/ZZQZ。默认为HS300
                       支持自定义指数,即dict of Series/dict of dict形式定义的benchmark
     :param price_type: str, 估值价格，取值范围open/close,默认open.
             open 为使用开盘价进行组合估值，close 为使用收盘价进行组合估值。
@@ -260,13 +256,13 @@ def limit_active_risk(
     :param sector_exposure_upper_boundary: float/Series，行业因子暴露上限，默认为10
     :param risk_aversion: float,风险厌恶系数, >= 0，如果不传则默认为0
     :param soft_params: pd.DataFrame, 软约束参数
-    :param cash_boundary: list of float, 现金约束,默认[0.0,0.0],即默认为满仓约束,如果传[0.05,0.1],说明现金约束在5%～10%之间
+    :param cash_boundary: list of float, 现金约束,默认[0.0,0.01],即默认为满仓约束,如果传[0.05,0.1],说明现金约束在5%～10%之间
     :return: dict
     """
     if soft_params is None:
         soft_params = pd.DataFrame()
     if cash_boundary is None:
-        cash_boundary = [0.0, 0.0]
+        cash_boundary = [0.0, 0.01]
     if not print_validate_factor_frame(factor_frame):
         return
 
@@ -334,10 +330,10 @@ def limit_portfolio_risk(
     :param start_date: str, 'YYYYmmdd'
     :param end_date: str, 'YYYYmmdd'
     :param freq: str, 调仓频率，'day/week/month/quarter/semi-year'
-    :param universe: str or dict, 股票池。默认是HS300，目前支持HS300/ZZ500/ZZ700/ZZ800/TLQA,
+    :param universe: str or dict, 股票池。默认是HS300，目前支持HS300/ZZ500/ZZ700/ZZ800/TLQA/SH50/SC50/ZZ1000/ZZQZ,
             也可为dict of list，则为自定义universe
     :param benchmark: str/dict of Series/dict of dict, 优化基准。
-                      支持指数成份股 HS300/ZZ500/ZZ700/ZZ800/TLQA/risk_free/SH50。默认为HS300
+                      支持指数成份股 HS300/ZZ500/ZZ700/ZZ800/TLQA/risk_free/SH50/SC50/ZZ1000/ZZQZ。默认为HS300
                       支持自定义指数,即dict of Series/dict of dict形式定义的benchmark
     :param price_type: str, 估值价格，取值范围open/close,默认open.
             open 为使用开盘价进行组合估值，close 为使用收盘价进行组合估值。
@@ -356,13 +352,13 @@ def limit_portfolio_risk(
     :param sector_exposure_upper_boundary: float/Series，行业因子暴露上限，默认为10
     :param risk_aversion: float,风险厌恶系数, >= 0，如果不传则默认为0
     :param soft_params: pd.DataFrame, 软约束参数
-    :param cash_boundary: list of float, 现金约束,默认[0.0,0.0],即默认为满仓约束,如果传[0.05,0.1],说明现金约束在5%～10%之间
+    :param cash_boundary: list of float, 现金约束,默认[0.0,0.01],即默认为满仓约束,如果传[0.05,0.1],说明现金约束在5%～10%之间
     :return: dict
     """
     if soft_params is None:
         soft_params = pd.DataFrame()
     if cash_boundary is None:
-        cash_boundary = [0.0, 0.0]
+        cash_boundary = [0.0, 0.01]
     if not print_validate_factor_frame(factor_frame):
         return
 
