@@ -82,24 +82,24 @@ def print_validate_frequency(freq):
 
 
 def print_validate_universe(univ):
+    all_benchmark_list = ['HS300', 'ZZ500', 'ZZ700', 'ZZ800', 'TLQA', 'SH50', 'SC50', 'ZZ1000', 'ZZQZ']
     validation_result = _validate_field(
-        univ, ['SH50','HS300', 'ZZ500', 'TLQA', 'ZZ700', 'ZZ800'])
+        univ, all_benchmark_list)
     custom_universe = isinstance(univ, dict)
     validation_result = validation_result or custom_universe
     if not validation_result:
-        print('''universe参数：%s暂不支持，支持范围：[SH50/HS300/ZZ500/ZZ700/ZZ800/
-        TLQA]或者自定义universe''' % univ)
+        print('''universe参数：%s暂不支持，支持范围： %s或者自定义universe''' % (univ, '/'.join(all_benchmark_list)))
     return validation_result
 
 
 def print_validate_benchmark(benchmark):
+    all_benchmark_list = ['HS300', 'ZZ500', 'ZZ700', 'ZZ800', 'TLQA', 'risk_free', 'SH50', 'SC50', 'ZZ1000', 'ZZQZ']
     validation_result = benchmark is None or _validate_field(
-        benchmark, ['SH50','HS300', 'ZZ500', 'TLQA', 'ZZ700', 'ZZ800', 'risk_free'])
+        benchmark, all_benchmark_list)
     custom_benchmark = isinstance(benchmark, dict)
     validation_result = validation_result or custom_benchmark
     if not validation_result:
-        print('''benchmark参数：%s暂不支持，支持范围：None值或者[SH50/HS300/ZZ500/
-        ZZ700/ZZ800/TLQA/risk_free]或者自定义benchmark''' % benchmark)
+        print('''benchmark参数：%s暂不支持，支持范围：None值或者 %s或者自定义benchmark''' % (benchmark, '/'.join(all_benchmark_list)))
     return validation_result
 
 
