@@ -11,6 +11,7 @@ from .mfclient import neutralize, standardize, winsorize, simple_long_only, long
 from . import DataAPI
 
 from .version import __version__
+from .utils import format_print
 
 from .DataAPI import retry_interval, max_retries
 
@@ -23,5 +24,5 @@ try:
     from . import DataAPI
 except:
     import traceback
-    print(traceback.format_exc())
-    print('upgrade fail.')
\ No newline at end of file
+    format_print(traceback.format_exc(), with_date=True)
+    format_print('upgrade fail.', with_date=True)
\ No newline at end of file
