@@ -1,5 +1,26 @@
 # -*- coding: utf-8 -*-
 
+# 通联数据机密
+# --------------------------------------------------------------------
+# 通联数据股份公司版权所有 © 2013-2021
+#
+# 注意：本文所载所有信息均属于通联数据股份公司资产。本文所包含的知识和技术概念均属于
+# 通联数据产权，并可能由中国、美国和其他国家专利或申请中的专利所覆盖，并受商业秘密或
+# 版权法保护。
+# 除非事先获得通联数据股份公司书面许可，严禁传播文中信息或复制本材料。
+#
+# DataYes CONFIDENTIAL
+# --------------------------------------------------------------------
+# Copyright © 2013-2021 DataYes, All Rights Reserved.
+#
+# NOTICE: All information contained herein is the property of DataYes
+# Incorporated. The intellectual and technical concepts contained herein are
+# proprietary to DataYes Incorporated, and may be covered by China, U.S. and
+# Other Countries Patents, patents in process, and are protected by trade
+# secret or copyright law.
+# Dissemination of this information or reproduction of this material is
+# strictly forbidden unless prior written permission is obtained from DataYes.
+
 import requests
 import traceback
 import os
@@ -9,16 +30,16 @@ gw_env = os.getenv('gw_env', 'prd')
 
 if env == 'prd' or (env == 'local' and gw_env == 'prd'):
     server = ('10.22.220.82', 80, 'api.wmcloud.com', 443)
-    URL_PREFIX = 'https://{}.wmcloud.com'
-    EXT_MFHANDLER_HOST = 'https://gw.wmcloud.com/mercury_ops'
-    BRAIN_HOST = 'https://gw.wmcloud.com/mercury_brain'
-    PING_URL = "https://{}.wmcloud.com/mercury_community/w/ping"
+    URL_PREFIX = 'https://{}.datayes.com'
+    EXT_MFHANDLER_HOST = 'https://gw.datayes.com/mercury_ops'
+    BRAIN_HOST = 'https://gw.datayes.com/mercury_brain'
+    PING_URL = "https://{}.datayes.com/mercury_community/w/ping"
 else:
     server = ('10.22.220.42', 80, 'api.wmcloud-stg.com', 443)
     URL_PREFIX = 'https://{}.wmcloud-stg.com'
     EXT_MFHANDLER_HOST = 'https://gw.wmcloud-stg.com/mercury_ops'
     BRAIN_HOST = "https://gw.datayes-stg.com/mercury_brain"
-    PING_URL = 'https://{}.wmcloud-stg.com/mercury_community/w/ping'
+    PING_URL = 'https://{}.datayes-stg.com/mercury_community/w/ping'
 
 
 FOLDERS = []
